#ifndef NT2_INCLUDE_FUNCTIONS_IS_NOT_EQUAL_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_IS_NOT_EQUAL_HPP_INCLUDED

#include <nt2/operator/include/functions/is_not_equal.hpp>

#endif
